@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""Functions that wrap other functions.
+"""
+Functions that wrap other functions.
 
 .. versionadded:: 1.0.0
 """
@@ -10,39 +11,41 @@ import itertools
 import time
 
 import pydash as pyd
+
 from ._compat import _range, getfullargspec, iteritems
 
 
 __all__ = (
-    'after',
-    'ary',
-    'before',
-    'conjoin',
-    'curry',
-    'curry_right',
-    'debounce',
-    'delay',
-    'disjoin',
-    'flip',
-    'flow',
-    'flow_right',
-    'iterated',
-    'juxtapose',
-    'negate',
-    'once',
-    'over_args',
-    'partial',
-    'partial_right',
-    'rearg',
-    'spread',
-    'throttle',
-    'unary',
-    'wrap',
+    "after",
+    "ary",
+    "before",
+    "conjoin",
+    "curry",
+    "curry_right",
+    "debounce",
+    "delay",
+    "disjoin",
+    "flip",
+    "flow",
+    "flow_right",
+    "iterated",
+    "juxtapose",
+    "negate",
+    "once",
+    "over_args",
+    "partial",
+    "partial_right",
+    "rearg",
+    "spread",
+    "throttle",
+    "unary",
+    "wrap",
 )
 
 
 class After(object):
     """Wrap a function in an after context."""
+
     def __init__(self, func, n):
         try:
             n = int(n)
@@ -53,16 +56,17 @@ class After(object):
         self.n = n
         self.func = func
 
-    def __call__(self, *args, **kargs):
+    def __call__(self, *args, **kwargs):
         """Return results of :attr:`func` after :attr:`n` calls."""
         self.n -= 1
 
         if self.n <= 0:
-            return self.func(*args, **kargs)
+            return self.func(*args, **kwargs)
 
 
 class Ary(object):
     """Wrap a function in an ary context."""
+
     def __init__(self, func, n):
         try:
             n = int(n)
@@ -73,33 +77,36 @@ class Ary(object):
         self.n = n
         self.func = func
 
-    def __call__(self, *args, **kargs):
-        """Return results of :attr:`func` with arguments capped to :attr:`n`.
-        Only positional arguments are capped. Any number of keyword arguments
-        are allowed.
+    def __call__(self, *args, **kwargs):
+        """
+        Return results of :attr:`func` with arguments capped to :attr:`n`.
+
+        Only positional arguments are capped. Any number of keyword arguments are allowed.
         """
         if self.n is not None:
-            args = args[:self.n]
+            args = args[: self.n]
 
-        return self.func(*args, **kargs)
+        return self.func(*args, **kwargs)
 
 
 class Before(After):
     """Wrap a function in a before context."""
-    def __call__(self, *args, **kargs):
+
+    def __call__(self, *args, **kwargs):
         self.n -= 1
 
         if self.n > 0:
-            return self.func(*args, **kargs)
+            return self.func(*args, **kwargs)
 
 
 class Flow(object):
     """Wrap a function in a flow context."""
-    def __init__(self, *funcs, **kargs):
-        self.funcs = funcs
-        self.from_right = kargs.get('from_right', True)
 
-    def __call__(self, *args, **kargs):
+    def __init__(self, *funcs, **kwargs):
+        self.funcs = funcs
+        self.from_right = kwargs.get("from_right", True)
+
+    def __call__(self, *args, **kwargs):
         """Return results of composing :attr:`funcs`."""
         funcs = list(self.funcs)
         from_index = -1 if self.from_right else 0
@@ -107,20 +114,22 @@ class Flow(object):
         result = None
 
         while funcs:
-            result = funcs.pop(from_index)(*args, **kargs)
+            result = funcs.pop(from_index)(*args, **kwargs)
             args = (result,)
-            kargs = {}
+            kwargs = {}
 
         return result
 
 
 class Conjoin(object):
     """Wrap a set of functions in a conjoin context."""
+
     def __init__(self, *funcs):
         self.funcs = funcs
 
     def __call__(self, obj):
         """Return result of conjoin `obj` with :attr:`funcs` predicates."""
+
         def iteratee(item):
             return pyd.every(self.funcs, lambda func: func(item))
 
@@ -129,28 +138,27 @@ class Conjoin(object):
 
 class Curry(object):
     """Wrap a function in a curry context."""
-    def __init__(self, func, arity, args=None, kargs=None):
+
+    def __init__(self, func, arity, args=None, kwargs=None):
         self.func = func
-        self.arity = (len(getfullargspec(func).args) if arity is None
-                      else arity)
+        self.arity = len(getfullargspec(func).args) if arity is None else arity
         self.args = () if args is None else args
-        self.kargs = {} if kargs is None else kargs
+        self.kwargs = {} if kwargs is None else kwargs
 
-    def __call__(self, *args, **kargs):
-        """Store `args` and `kargs` and call :attr:`func` if we've reached or
-        exceeded the function arity.
-        """
+    def __call__(self, *args, **kwargs):
+        """Store `args` and `kwargs` and call :attr:`func` if we've reached or exceeded the function
+        arity."""
         args = self.compose_args(args)
-        kargs.update(self.kargs)
+        kwargs.update(self.kwargs)
 
-        if (len(args) + len(kargs)) >= self.arity:
-            args_arity = self.arity - len(kargs)
-            args = args[:(args_arity if args_arity > 0 else 0)]
-            curried = self.func(*args, **kargs)
+        if (len(args) + len(kwargs)) >= self.arity:
+            args_arity = self.arity - len(kwargs)
+            args = args[: (args_arity if args_arity > 0 else 0)]
+            curried = self.func(*args, **kwargs)
         else:
             # NOTE: Use self.__class__ so that subclasses will use their own
             # class to generate next iteration of call.
-            curried = self.__class__(self.func, self.arity, args, kargs)
+            curried = self.__class__(self.func, self.arity, args, kwargs)
 
         return curried
 
@@ -161,12 +169,14 @@ class Curry(object):
 
 class CurryRight(Curry):
     """Wrap a function in a curry-right context."""
+
     def compose_args(self, new_args):
         return tuple(list(new_args) + list(self.args))
 
 
 class Debounce(object):
     """Wrap a function in a debounce context."""
+
     def __init__(self, func, wait, max_wait=False):
         self.func = func
         self.wait = wait
@@ -177,20 +187,21 @@ class Debounce(object):
         # Initialize last_* times to be prior to the wait periods so that func
         # is primed to be executed on first call.
         self.last_call = pyd.now() - self.wait
-        self.last_execution = (pyd.now() - max_wait if pyd.is_number(max_wait)
-                               else None)
+        self.last_execution = pyd.now() - max_wait if pyd.is_number(max_wait) else None
+
+    def __call__(self, *args, **kwargs):
+        """
+        Execute :attr:`func` if function hasn't been called witinin last :attr:`wait` milliseconds
+        or in last :attr:`max_wait` milliseconds.
 
-    def __call__(self, *args, **kargs):
-        """Execute :attr:`func` if function hasn't been called witinin last
-        :attr:`wait` milliseconds or in last :attr:`max_wait` milliseconds.
         Return results of last successful call.
         """
         present = pyd.now()
 
-        if ((present - self.last_call) >= self.wait or
-                (self.max_wait and
-                 (present - self.last_execution) >= self.max_wait)):
-            self.last_result = self.func(*args, **kargs)
+        if (present - self.last_call) >= self.wait or (
+            self.max_wait and (present - self.last_execution) >= self.max_wait
+        ):
+            self.last_result = self.func(*args, **kwargs)
             self.last_execution = present
 
         self.last_call = present
@@ -200,11 +211,13 @@ class Debounce(object):
 
 class Disjoin(object):
     """Wrap a set of functions in a disjoin context."""
+
     def __init__(self, *funcs):
         self.funcs = funcs
 
     def __call__(self, obj):
         """Return result of disjoin `obj` with :attr:`funcs` predicates."""
+
         def iteratee(item):
             return pyd.some(self.funcs, lambda func: func(item))
 
@@ -213,15 +226,17 @@ class Disjoin(object):
 
 class Flip(object):
     """Wrap a function in a flip context."""
+
     def __init__(self, func):
         self.func = func
 
-    def __call__(self, *args, **kargs):
-        return self.func(*reversed(args), **kargs)
+    def __call__(self, *args, **kwargs):
+        return self.func(*reversed(args), **kwargs)
 
 
 class Iterated(object):
     """Wrap a function in an iterated context."""
+
     def __init__(self, func):
         self.func = func
 
@@ -233,9 +248,7 @@ class Iterated(object):
             yield value
 
     def __call__(self, initial, n):
-        """Return value of calling :attr:`func` `n` times using `initial` as
-        seed value.
-        """
+        """Return value of calling :attr:`func` `n` times using `initial` as seed value."""
         value = initial
         iteration = self._iteration(value)
 
@@ -247,6 +260,7 @@ class Iterated(object):
 
 class Juxtapose(object):
     """Wrap a function in a juxtapose context."""
+
     def __init__(self, *funcs):
         self.funcs = funcs
 
@@ -256,6 +270,7 @@ class Juxtapose(object):
 
 class OverArgs(object):
     """Wrap a function in a over_args context."""
+
     def __init__(self, func, *transforms):
         self.func = func
         self.transforms = pyd.flatten(transforms)
@@ -267,25 +282,27 @@ class OverArgs(object):
 
 class Negate(object):
     """Wrap a function in a negate context."""
+
     def __init__(self, func):
         self.func = func
 
-    def __call__(self, *args, **kargs):
+    def __call__(self, *args, **kwargs):
         """Return negated results of calling :attr:`func`."""
-        return not self.func(*args, **kargs)
+        return not self.func(*args, **kwargs)
 
 
 class Once(object):
     """Wrap a function in a once context."""
+
     def __init__(self, func):
         self.func = func
         self.result = None
         self.called = False
 
-    def __call__(self, *args, **kargs):
+    def __call__(self, *args, **kwargs):
         """Return results from the first call of :attr:`func`."""
         if not self.called:
-            self.result = self.func(*args, **kargs)
+            self.result = self.func(*args, **kwargs)
             self.called = True
 
         return self.result
@@ -293,44 +310,47 @@ class Once(object):
 
 class Partial(object):
     """Wrap a function in a partial context."""
-    def __init__(self, func, args, kargs=None, from_right=False):
+
+    def __init__(self, func, args, kwargs=None, from_right=False):
         self.func = func
         self.args = args
-        self.kargs = kargs or {}
+        self.kwargs = kwargs or {}
         self.from_right = from_right
 
-    def __call__(self, *args, **kargs):
-        """Return results from :attr:`func` with :attr:`args` + `args`. Apply
-        arguments from left or right depending on :attr:`from_right`.
+    def __call__(self, *args, **kwargs):
+        """
+        Return results from :attr:`func` with :attr:`args` + `args`.
+
+        Apply arguments from left or right depending on :attr:`from_right`.
         """
         if self.from_right:
             args = itertools.chain(args, self.args)
         else:
             args = itertools.chain(self.args, args)
 
-        kargs = dict(itertools.chain(iteritems(self.kargs), iteritems(kargs)))
+        kwargs = dict(itertools.chain(iteritems(self.kwargs), iteritems(kwargs)))
 
-        return self.func(*args, **kargs)
+        return self.func(*args, **kwargs)
 
 
 class Rearg(object):
     """Wrap a function in a rearg context."""
+
     def __init__(self, func, *indexes):
         self.func = func
 
-        # Index `indexes` by the index value so we can do a lookup mapping by
-        # walking the function arguments.
+        # Index `indexes` by the index value so we can do a lookup mapping by walking the function
+        # arguments.
         self.indexes = dict(
-            (src_index, dest_index)
-            for dest_index, src_index in enumerate(pyd.flatten(indexes)))
+            (src_index, dest_index) for dest_index, src_index in enumerate(pyd.flatten(indexes))
+        )
 
-    def __call__(self, *args, **kargs):
+    def __call__(self, *args, **kwargs):
         """Return results from :attr:`func` using rearranged arguments."""
         reargs = {}
         rest = []
 
-        # Walk arguments to ensure each one is added to the final argument
-        # list.
+        # Walk arguments to ensure each one is added to the final argument list.
         for src_index, arg in enumerate(args):
             # NOTE: dest_index will range from 0 to len(indexes).
             dest_index = self.indexes.get(src_index)
@@ -339,19 +359,19 @@ class Rearg(object):
                 # Remap argument index.
                 reargs[dest_index] = arg
             else:
-                # Argumnet index is not contained in `indexes` so stick in the
-                # back.
+                # Argumnet index is not contained in `indexes` so stick in the back.
                 rest.append(arg)
 
         args = itertools.chain((reargs[key] for key in sorted(reargs)), rest)
 
-        return self.func(*args, **kargs)
+        return self.func(*args, **kwargs)
 
 
 class Spread(object):
     """Wrap a function in a spread context."""
+
     def __init__(self, func):
-        self. func = func
+        self.func = func
 
     def __call__(self, args):
         """Return results from :attr:`func` using array of `args` provided."""
@@ -360,6 +380,7 @@ class Spread(object):
 
 class Throttle(object):
     """Wrap a function in a throttle context."""
+
     def __init__(self, func, wait):
         self.func = func
         self.wait = wait
@@ -367,25 +388,28 @@ class Throttle(object):
         self.last_result = None
         self.last_execution = pyd.now() - self.wait
 
-    def __call__(self, *args, **kargs):
-        """Execute :attr:`func` if function hasn't been called witinin last
-        :attr:`wait` milliseconds. Return results of last successful call.
+    def __call__(self, *args, **kwargs):
+        """
+        Execute :attr:`func` if function hasn't been called witinin last :attr:`wait` milliseconds.
+
+        Return results of last successful call.
         """
         present = pyd.now()
 
         if (present - self.last_execution) >= self.wait:
-            self.last_result = self.func(*args, **kargs)
+            self.last_result = self.func(*args, **kwargs)
             self.last_execution = present
 
         return self.last_result
 
 
 def after(func, n):
-    """Creates a function that executes `func`, with the arguments of the
-    created function, only after being called `n` times.
+    """
+    Creates a function that executes `func`, with the arguments of the created function, only after
+    being called `n` times.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         n (int): Number of times `func` must be called before it is executed.
 
     Returns:
@@ -411,12 +435,12 @@ def after(func, n):
 
 
 def ary(func, n):
-    """Creates a function that accepts up to `n` arguments ignoring any
-    additional arguments. Only positional arguments are capped. All keyword
-    arguments are allowed through.
+    """
+    Creates a function that accepts up to `n` arguments ignoring any additional arguments. Only
+    positional arguments are capped. All keyword arguments are allowed through.
 
     Args:
-        func (function): Function to cap arguments for.
+        func (callable): Function to cap arguments for.
         n (int): Number of arguments to accept.
 
     Returns:
@@ -437,11 +461,12 @@ def ary(func, n):
 
 
 def before(func, n):
-    """Creates a function that executes `func`, with the arguments of the
-    created function, until it has been called `n` times.
+    """
+    Creates a function that executes `func`, with the arguments of the created function, until it
+    has been called `n` times.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         n (int): Number of times `func` may be executed.
 
     Returns:
@@ -467,12 +492,12 @@ def before(func, n):
 
 
 def conjoin(*funcs):
-    """Creates a function that composes multiple predicate functions into a
-    single predicate that tests whether **all** elements of an object pass each
-    predicate.
+    """
+    Creates a function that composes multiple predicate functions into a single predicate that tests
+    whether **all** elements of an object pass each predicate.
 
     Args:
-        *funcs (function): Function(s) to conjoin.
+        *funcs (callable): Function(s) to conjoin.
 
     Returns:
         Conjoin: Function(s) wrapped in a :class:`Conjoin` context.
@@ -495,16 +520,15 @@ def conjoin(*funcs):
 
 
 def curry(func, arity=None):
-    """Creates a function that accepts one or more arguments of `func` that
-    when invoked either executes `func` returning its result (if all `func`
-    arguments have been provided) or returns a function that accepts one or
-    more of the remaining `func` arguments, and so on.
+    """
+    Creates a function that accepts one or more arguments of `func` that when invoked either
+    executes `func` returning its result (if all `func` arguments have been provided) or returns a
+    function that accepts one or more of the remaining `func` arguments, and so on.
 
     Args:
-        func (function): Function to curry.
-        arity (int, optional): Number of function arguments that can be
-            accepted by curried function. Default is to use the number of
-            arguments that are accepted by `func`.
+        func (callable): Function to curry.
+        arity (int, optional): Number of function arguments that can be accepted by curried
+            function. Default is to use the number of arguments that are accepted by `func`.
 
     Returns:
         Curry: Function wrapped in a :class:`Curry` context.
@@ -527,14 +551,14 @@ def curry(func, arity=None):
 
 
 def curry_right(func, arity=None):
-    """This method is like :func:`curry` except that arguments are applied to
-    `func` in the manner of :func:`partial_right` instead of :func:`partial`.
+    """
+    This method is like :func:`curry` except that arguments are applied to `func` in the manner of
+    :func:`partial_right` instead of :func:`partial`.
 
     Args:
-        func (function): Function to curry.
-        arity (int, optional): Number of function arguments that can be
-            accepted by curried function. Default is to use the number of
-            arguments that are accepted by `func`.
+        func (callable): Function to curry.
+        arity (int, optional): Number of function arguments that can be accepted by curried
+            function. Default is to use the number of arguments that are accepted by `func`.
 
     Returns:
         CurryRight: Function wrapped in a :class:`CurryRight` context.
@@ -557,13 +581,13 @@ def curry_right(func, arity=None):
 
 
 def debounce(func, wait, max_wait=False):
-    """Creates a function that will delay the execution of `func` until after
-    `wait` milliseconds have elapsed since the last time it was invoked.
-    Subsequent calls to the debounced function will return the result of the
-    last `func` call.
+    """
+    Creates a function that will delay the execution of `func` until after `wait` milliseconds have
+    elapsed since the last time it was invoked. Subsequent calls to the debounced function will
+    return the result of the last `func` call.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         wait (int): Milliseconds to wait before executing `func`.
         max_wait (optional): Maximum time to wait before executing `func`.
 
@@ -575,15 +599,16 @@ def debounce(func, wait, max_wait=False):
     return Debounce(func, wait, max_wait=max_wait)
 
 
-def delay(func, wait, *args, **kargs):
-    """Executes the `func` function after `wait` milliseconds. Additional
-    arguments will be provided to `func` when it is invoked.
+def delay(func, wait, *args, **kwargs):
+    """
+    Executes the `func` function after `wait` milliseconds. Additional arguments will be provided to
+    `func` when it is invoked.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         wait (int): Milliseconds to wait before executing `func`.
         *args (optional): Arguments to pass to `func`.
-        **kargs (optional): Keyword arguments to pass to `func`.
+        **kwargs (optional): Keyword arguments to pass to `func`.
 
     Returns:
         mixed: Return from `func`.
@@ -591,16 +616,16 @@ def delay(func, wait, *args, **kargs):
     .. versionadded:: 1.0.0
     """
     time.sleep(wait / 1000.0)
-    return func(*args, **kargs)
+    return func(*args, **kwargs)
 
 
 def disjoin(*funcs):
-    """Creates a function that composes multiple predicate functions into a
-    single predicate that tests whether **any** elements of an object pass each
-    predicate.
+    """
+    Creates a function that composes multiple predicate functions into a single predicate that tests
+    whether **any** elements of an object pass each predicate.
 
     Args:
-        *funcs (function): Function(s) to disjoin.
+        *funcs (callable): Function(s) to disjoin.
 
     Returns:
         Disjoin: Function(s) wrapped in a :class:`Disjoin` context.
@@ -622,10 +647,11 @@ def disjoin(*funcs):
 
 
 def flip(func):
-    """Creates a function that invokes the method with arguments reversed.
+    """
+    Creates a function that invokes the method with arguments reversed.
 
     Args:
-        func (function): Function to flip arguments for.
+        func (callable): Function to flip arguments for.
 
     Returns:
         function: Function wrapped in a :class:`Flip` context.
@@ -645,13 +671,13 @@ def flip(func):
 
 
 def flow(*funcs):
-    """Creates a function that is the composition of the provided functions,
-    where each successive invocation is supplied the return value of the
-    previous. For example, composing the functions ``f()``, ``g()``, and
-    ``h()`` produces ``h(g(f()))``.
+    """
+    Creates a function that is the composition of the provided functions, where each successive
+    invocation is supplied the return value of the previous. For example, composing the functions
+    ``f()``, ``g()``, and ``h()`` produces ``h(g(f()))``.
 
     Args:
-        *funcs (function): Function(s) to compose.
+        *funcs (callable): Function(s) to compose.
 
     Returns:
         Flow: Function(s) wrapped in a :class:`Flow` context.
@@ -677,13 +703,13 @@ def flow(*funcs):
 
 
 def flow_right(*funcs):
-    """This function is like :func:`flow` except that it creates a function
-    that invokes the provided functions from right to left. For example,
-    composing the functions ``f()``, ``g()``, and ``h()`` produces
-    ``f(g(h()))``.
+    """
+    This function is like :func:`flow` except that it creates a function that invokes the provided
+    functions from right to left. For example, composing the functions ``f()``, ``g()``, and ``h()``
+    produces ``f(g(h()))``.
 
     Args:
-        *funcs (function): Function(s) to compose.
+        *funcs (callable): Function(s) to compose.
 
     Returns:
         Flow: Function(s) wrapped in a :class:`Flow` context.
@@ -712,14 +738,14 @@ def flow_right(*funcs):
 
 
 def iterated(func):
-    """Creates a function that is composed with itself. Each call to the
-    iterated function uses the previous function call's result as input.
-    Returned :class:`Iterated` instance can be called with ``(initial, n)``
-    where `initial` is the initial value to seed `func` with and `n` is the
-    number of times to call `func`.
+    """
+    Creates a function that is composed with itself. Each call to the iterated function uses the
+    previous function call's result as input. Returned :class:`Iterated` instance can be called with
+    ``(initial, n)`` where `initial` is the initial value to seed `func` with and `n` is the number
+    of times to call `func`.
 
     Args:
-        func (function): Function to iterate.
+        func (callable): Function to iterate.
 
     Returns:
         Iterated: Function wrapped in a :class:`Iterated` context.
@@ -738,11 +764,12 @@ def iterated(func):
 
 
 def juxtapose(*funcs):
-    """Creates a function whose return value is a list of the results of
-    calling each `funcs` with the supplied arguments.
+    """
+    Creates a function whose return value is a list of the results of calling each `funcs` with the
+    supplied arguments.
 
     Args:
-        *funcs (function): Function(s) to juxtapose.
+        *funcs (callable): Function(s) to juxtapose.
 
     Returns:
         Juxtapose: Function wrapped in a :class:`Juxtapose` context.
@@ -762,11 +789,12 @@ def juxtapose(*funcs):
 
 
 def negate(func):
-    """Creates a function that negates the result of the predicate `func`. The
-    `func` function is executed with the arguments of the created function.
+    """
+    Creates a function that negates the result of the predicate `func`. The `func` function is
+    executed with the arguments of the created function.
 
     Args:
-        func (function): Function to negate execute.
+        func (callable): Function to negate execute.
 
     Returns:
         Negate: Function wrapped in a :class:`Negate` context.
@@ -785,11 +813,12 @@ def negate(func):
 
 
 def once(func):
-    """Creates a function that is restricted to execute `func` once. Repeat
-    calls to the function will return the value of the first call.
+    """
+    Creates a function that is restricted to execute `func` once. Repeat calls to the function will
+    return the value of the first call.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
 
     Returns:
         Once: Function wrapped in a :class:`Once` context.
@@ -808,13 +837,13 @@ def once(func):
 
 
 def over_args(func, *transforms):
-    """Creates a function that runs each argument through a corresponding
-    transform function.
+    """
+    Creates a function that runs each argument through a corresponding transform function.
 
     Args:
-        func (function): Function to wrap.
-        *transforms (function): Functions to transform arguments, specified as
-            individual functions or lists of functions.
+        func (callable): Function to wrap.
+        *transforms (callable): Functions to transform arguments, specified as individual functions
+            or lists of functions.
 
     Returns:
         OverArgs: Function wrapped in a :class:`OverArgs` context.
@@ -835,14 +864,15 @@ def over_args(func, *transforms):
     return OverArgs(func, *transforms)
 
 
-def partial(func, *args, **kargs):
-    """Creates a function that, when called, invokes `func` with any additional
-    partial arguments prepended to those provided to the new function.
+def partial(func, *args, **kwargs):
+    """
+    Creates a function that, when called, invokes `func` with any additional partial arguments
+    prepended to those provided to the new function.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         *args (optional): Partial arguments to prepend to function call.
-        **kargs (optional): Partial keyword arguments to bind to function call.
+        **kwargs (optional): Partial keyword arguments to bind to function call.
 
     Returns:
         Partial: Function wrapped in a :class:`Partial` context.
@@ -860,17 +890,18 @@ def partial(func, *args, **kargs):
 
     .. versionadded:: 1.0.0
     """
-    return Partial(func, args, kargs)
+    return Partial(func, args, kwargs)
 
 
-def partial_right(func, *args, **kargs):
-    """This method is like :func:`partial` except that partial arguments are
-    appended to those provided to the new function.
+def partial_right(func, *args, **kwargs):
+    """
+    This method is like :func:`partial` except that partial arguments are appended to those provided
+    to the new function.
 
     Args:
-        func (function): Function to execute.
+        func (callable): Function to execute.
         *args (optional): Partial arguments to append to function call.
-        **kargs (optional): Partial keyword arguments to bind to function call.
+        **kwargs (optional): Partial keyword arguments to bind to function call.
 
     Returns:
         Partial: Function wrapped in a :class:`Partial` context.
@@ -883,17 +914,17 @@ def partial_right(func, *args, **kargs):
 
     .. versionadded:: 1.0.0
     """
-    return Partial(func, args, kargs, from_right=True)
+    return Partial(func, args, kwargs, from_right=True)
 
 
 def rearg(func, *indexes):
-    """Creates a function that invokes `func` with arguments arranged according
-    to the specified indexes where the argument value at the first index is
-    provided as the first argument, the argument value at the second index is
-    provided as the second argument, and so on.
+    """
+    Creates a function that invokes `func` with arguments arranged according to the specified
+    indexes where the argument value at the first index is provided as the first argument, the
+    argument value at the second index is provided as the second argument, and so on.
 
     Args:
-        func (function): Function to rearrange arguments for.
+        func (callable): Function to rearrange arguments for.
         *indexes (int): The arranged argument indexes.
 
     Returns:
@@ -913,11 +944,12 @@ def rearg(func, *indexes):
 
 
 def spread(func):
-    """Creates a function that invokes `func` with the array of arguments
-    provided to the created function.
+    """
+    Creates a function that invokes `func` with the array of arguments provided to the created
+    function.
 
     Args:
-        func (function): Function to spread.
+        func (callable): Function to spread.
 
     Returns:
         Spread: Function wrapped in a :class:`Spread` context.
@@ -934,12 +966,13 @@ def spread(func):
 
 
 def throttle(func, wait):
-    """Creates a function that, when executed, will only call the `func`
-    function at most once per every `wait` milliseconds. Subsequent calls to
-    the throttled function will return the result of the last `func` call.
+    """
+    Creates a function that, when executed, will only call the `func` function at most once per
+    every `wait` milliseconds. Subsequent calls to the throttled function will return the result of
+    the last `func` call.
 
     Args:
-        func (function): Function to throttle.
+        func (callable): Function to throttle.
         wait (int): Milliseconds to wait before calling `func` again.
 
     Returns:
@@ -951,11 +984,11 @@ def throttle(func, wait):
 
 
 def unary(func):
-    """Creates a function that accepts up to one argument, ignoring any
-    additional arguments.
+    """
+    Creates a function that accepts up to one argument, ignoring any additional arguments.
 
     Args:
-        func (function): Function to cap arguments for.
+        func (callable): Function to cap arguments for.
 
     Returns:
         Ary: Function wrapped in an :class:`Ary` context.
@@ -975,13 +1008,13 @@ def unary(func):
 
 
 def wrap(value, func):
-    """Creates a function that provides value to the wrapper function as its
-    first argument. Additional arguments provided to the function are appended
-    to those provided to the wrapper function.
+    """
+    Creates a function that provides value to the wrapper function as its first argument. Additional
+    arguments provided to the function are appended to those provided to the wrapper function.
 
     Args:
         value (mixed): Value provided as first argument to function call.
-        func (function): Function to execute.
+        func (callable): Function to execute.
 
     Returns:
         Partial: Function wrapped in a :class:`Partial` context.
